@@ -1768,9 +1768,10 @@ class Model:
             ]
         )
 
-        for rxn in self.reactions.values():
-            c_rxn = cobra.Reaction(id=rxn.id)
-            model.add_reaction(c_rxn)
+        model.add_reactions([cobra.Reaction(id=rxn.id) for rxn in self.reactions.values()])
+
+        for name, rxn in self.reactions.items():
+            c_rxn = model.reactions.get_by_id(name)
             c_rxn.bounds = rxn.bounds if rxn.bounds else (0, 1000)
             c_rxn.add_metabolites(rxn.stoichiometries)
 
